.. Hiperwalk documentation master file, created by
   sphinx-quickstart on Wed May 11 11:03:45 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Hiperwalk!
=====================

**Hiperwalk**, an acronym for High-Performance Quantum Walk Simulator, is a powerful, 
open-source software designed to simulate quantum walks on various 
graph structures. Leveraging heterogeneous High-Performance Computing (HPC), Hiperwalk 
enables users to harness their computer's parallel resources, including multicore 
CPUs, General-Purpose GPUs, and accelerator cards, for substantial speed enhancements. 
This high-level optimization is made user-friendly as it doesn't require a parallel 
programming background. Hiperwalk is an ongoing project, using 
the capabilities of Python, C, OpenCL, among other languages, to provide a robust 
and efficient environment for the simulation of quantum walks and spatial search algorithms.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   install/index
   tutorial/index
   documentation/index
   development/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
